Class: Aws::AuditManager::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::AuditManager::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-auditmanager/client.rb,
sig/client.rbs
Overview
An API client for AuditManager. To construct a client, you need to configure a :region and :credentials.
client = Aws::AuditManager::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateAssessmentReportEvidenceFolderResponseSuccess, _BatchAssociateAssessmentReportEvidenceResponseSuccess, _BatchCreateDelegationByAssessmentResponseSuccess, _BatchDeleteDelegationByAssessmentResponseSuccess, _BatchDisassociateAssessmentReportEvidenceResponseSuccess, _BatchImportEvidenceToAssessmentControlResponseSuccess, _CreateAssessmentFrameworkResponseSuccess, _CreateAssessmentReportResponseSuccess, _CreateAssessmentResponseSuccess, _CreateControlResponseSuccess, _DeleteAssessmentFrameworkResponseSuccess, _DeleteAssessmentFrameworkShareResponseSuccess, _DeleteAssessmentReportResponseSuccess, _DeleteAssessmentResponseSuccess, _DeleteControlResponseSuccess, _DeregisterAccountResponseSuccess, _DeregisterOrganizationAdminAccountResponseSuccess, _DisassociateAssessmentReportEvidenceFolderResponseSuccess, _GetAccountStatusResponseSuccess, _GetAssessmentFrameworkResponseSuccess, _GetAssessmentReportUrlResponseSuccess, _GetAssessmentResponseSuccess, _GetChangeLogsResponseSuccess, _GetControlResponseSuccess, _GetDelegationsResponseSuccess, _GetEvidenceByEvidenceFolderResponseSuccess, _GetEvidenceFileUploadUrlResponseSuccess, _GetEvidenceFolderResponseSuccess, _GetEvidenceFoldersByAssessmentControlResponseSuccess, _GetEvidenceFoldersByAssessmentResponseSuccess, _GetEvidenceResponseSuccess, _GetInsightsByAssessmentResponseSuccess, _GetInsightsResponseSuccess, _GetOrganizationAdminAccountResponseSuccess, _GetServicesInScopeResponseSuccess, _GetSettingsResponseSuccess, _ListAssessmentControlInsightsByControlDomainResponseSuccess, _ListAssessmentFrameworkShareRequestsResponseSuccess, _ListAssessmentFrameworksResponseSuccess, _ListAssessmentReportsResponseSuccess, _ListAssessmentsResponseSuccess, _ListControlDomainInsightsByAssessmentResponseSuccess, _ListControlDomainInsightsResponseSuccess, _ListControlInsightsByControlDomainResponseSuccess, _ListControlsResponseSuccess, _ListKeywordsForDataSourceResponseSuccess, _ListNotificationsResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterAccountResponseSuccess, _RegisterOrganizationAdminAccountResponseSuccess, _StartAssessmentFrameworkShareResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAssessmentControlResponseSuccess, _UpdateAssessmentControlSetStatusResponseSuccess, _UpdateAssessmentFrameworkResponseSuccess, _UpdateAssessmentFrameworkShareResponseSuccess, _UpdateAssessmentResponseSuccess, _UpdateAssessmentStatusResponseSuccess, _UpdateControlResponseSuccess, _UpdateSettingsResponseSuccess, _ValidateAssessmentReportIntegrityResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_assessment_report_evidence_folder(params = {}) ⇒ Struct
Associates an evidence folder to an assessment report in an Audit Manager assessment.
-
#batch_associate_assessment_report_evidence(params = {}) ⇒ Types::BatchAssociateAssessmentReportEvidenceResponse
Associates a list of evidence to an assessment report in an Audit Manager assessment.
-
#batch_create_delegation_by_assessment(params = {}) ⇒ Types::BatchCreateDelegationByAssessmentResponse
Creates a batch of delegations for an assessment in Audit Manager.
-
#batch_delete_delegation_by_assessment(params = {}) ⇒ Types::BatchDeleteDelegationByAssessmentResponse
Deletes a batch of delegations for an assessment in Audit Manager.
-
#batch_disassociate_assessment_report_evidence(params = {}) ⇒ Types::BatchDisassociateAssessmentReportEvidenceResponse
Disassociates a list of evidence from an assessment report in Audit Manager.
-
#batch_import_evidence_to_assessment_control(params = {}) ⇒ Types::BatchImportEvidenceToAssessmentControlResponse
Adds one or more pieces of evidence to a control in an Audit Manager assessment.
-
#create_assessment(params = {}) ⇒ Types::CreateAssessmentResponse
Creates an assessment in Audit Manager.
-
#create_assessment_framework(params = {}) ⇒ Types::CreateAssessmentFrameworkResponse
Creates a custom framework in Audit Manager.
-
#create_assessment_report(params = {}) ⇒ Types::CreateAssessmentReportResponse
Creates an assessment report for the specified assessment.
-
#create_control(params = {}) ⇒ Types::CreateControlResponse
Creates a new custom control in Audit Manager.
-
#delete_assessment(params = {}) ⇒ Struct
Deletes an assessment in Audit Manager.
-
#delete_assessment_framework(params = {}) ⇒ Struct
Deletes a custom framework in Audit Manager.
-
#delete_assessment_framework_share(params = {}) ⇒ Struct
Deletes a share request for a custom framework in Audit Manager.
-
#delete_assessment_report(params = {}) ⇒ Struct
Deletes an assessment report in Audit Manager.
-
#delete_control(params = {}) ⇒ Struct
Deletes a custom control in Audit Manager.
-
#deregister_account(params = {}) ⇒ Types::DeregisterAccountResponse
Deregisters an account in Audit Manager.
-
#deregister_organization_admin_account(params = {}) ⇒ Struct
Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager.
-
#disassociate_assessment_report_evidence_folder(params = {}) ⇒ Struct
Disassociates an evidence folder from the specified assessment report in Audit Manager.
-
#get_account_status(params = {}) ⇒ Types::GetAccountStatusResponse
Gets the registration status of an account in Audit Manager.
-
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Gets information about a specified assessment.
-
#get_assessment_framework(params = {}) ⇒ Types::GetAssessmentFrameworkResponse
Gets information about a specified framework.
-
#get_assessment_report_url(params = {}) ⇒ Types::GetAssessmentReportUrlResponse
Gets the URL of an assessment report in Audit Manager.
-
#get_change_logs(params = {}) ⇒ Types::GetChangeLogsResponse
Gets a list of changelogs from Audit Manager.
-
#get_control(params = {}) ⇒ Types::GetControlResponse
Gets information about a specified control.
-
#get_delegations(params = {}) ⇒ Types::GetDelegationsResponse
Gets a list of delegations from an audit owner to a delegate.
-
#get_evidence(params = {}) ⇒ Types::GetEvidenceResponse
Gets information about a specified evidence item.
-
#get_evidence_by_evidence_folder(params = {}) ⇒ Types::GetEvidenceByEvidenceFolderResponse
Gets all evidence from a specified evidence folder in Audit Manager.
-
#get_evidence_file_upload_url(params = {}) ⇒ Types::GetEvidenceFileUploadUrlResponse
Creates a presigned Amazon S3 URL that can be used to upload a file as manual evidence.
-
#get_evidence_folder(params = {}) ⇒ Types::GetEvidenceFolderResponse
Gets an evidence folder from a specified assessment in Audit Manager.
-
#get_evidence_folders_by_assessment(params = {}) ⇒ Types::GetEvidenceFoldersByAssessmentResponse
Gets the evidence folders from a specified assessment in Audit Manager.
-
#get_evidence_folders_by_assessment_control(params = {}) ⇒ Types::GetEvidenceFoldersByAssessmentControlResponse
Gets a list of evidence folders that are associated with a specified control in an Audit Manager assessment.
-
#get_insights(params = {}) ⇒ Types::GetInsightsResponse
Gets the latest analytics data for all your current active assessments.
-
#get_insights_by_assessment(params = {}) ⇒ Types::GetInsightsByAssessmentResponse
Gets the latest analytics data for a specific active assessment.
-
#get_organization_admin_account(params = {}) ⇒ Types::GetOrganizationAdminAccountResponse
Gets the name of the delegated Amazon Web Services administrator account for a specified organization.
-
#get_services_in_scope(params = {}) ⇒ Types::GetServicesInScopeResponse
Gets a list of the Amazon Web Services services from which Audit Manager can collect evidence.
-
#get_settings(params = {}) ⇒ Types::GetSettingsResponse
Gets the settings for a specified Amazon Web Services account.
-
#list_assessment_control_insights_by_control_domain(params = {}) ⇒ Types::ListAssessmentControlInsightsByControlDomainResponse
Lists the latest analytics data for controls within a specific control domain and a specific active assessment.
-
#list_assessment_framework_share_requests(params = {}) ⇒ Types::ListAssessmentFrameworkShareRequestsResponse
Returns a list of sent or received share requests for custom frameworks in Audit Manager.
-
#list_assessment_frameworks(params = {}) ⇒ Types::ListAssessmentFrameworksResponse
Returns a list of the frameworks that are available in the Audit Manager framework library.
-
#list_assessment_reports(params = {}) ⇒ Types::ListAssessmentReportsResponse
Returns a list of assessment reports created in Audit Manager.
-
#list_assessments(params = {}) ⇒ Types::ListAssessmentsResponse
Returns a list of current and past assessments from Audit Manager.
-
#list_control_domain_insights(params = {}) ⇒ Types::ListControlDomainInsightsResponse
Lists the latest analytics data for control domains across all of your active assessments.
-
#list_control_domain_insights_by_assessment(params = {}) ⇒ Types::ListControlDomainInsightsByAssessmentResponse
Lists analytics data for control domains within a specified active assessment.
-
#list_control_insights_by_control_domain(params = {}) ⇒ Types::ListControlInsightsByControlDomainResponse
Lists the latest analytics data for controls within a specific control domain across all active assessments.
-
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a list of controls from Audit Manager.
-
#list_keywords_for_data_source(params = {}) ⇒ Types::ListKeywordsForDataSourceResponse
Returns a list of keywords that are pre-mapped to the specified control data source.
-
#list_notifications(params = {}) ⇒ Types::ListNotificationsResponse
Returns a list of all Audit Manager notifications.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource in Audit Manager.
-
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
Enables Audit Manager for the specified Amazon Web Services account.
-
#register_organization_admin_account(params = {}) ⇒ Types::RegisterOrganizationAdminAccountResponse
Enables an Amazon Web Services account within the organization as the delegated administrator for Audit Manager.
-
#start_assessment_framework_share(params = {}) ⇒ Types::StartAssessmentFrameworkShareResponse
Creates a share request for a custom framework in Audit Manager.
-
#tag_resource(params = {}) ⇒ Struct
Tags the specified resource in Audit Manager.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource in Audit Manager.
-
#update_assessment(params = {}) ⇒ Types::UpdateAssessmentResponse
Edits an Audit Manager assessment.
-
#update_assessment_control(params = {}) ⇒ Types::UpdateAssessmentControlResponse
Updates a control within an assessment in Audit Manager.
-
#update_assessment_control_set_status(params = {}) ⇒ Types::UpdateAssessmentControlSetStatusResponse
Updates the status of a control set in an Audit Manager assessment.
-
#update_assessment_framework(params = {}) ⇒ Types::UpdateAssessmentFrameworkResponse
Updates a custom framework in Audit Manager.
-
#update_assessment_framework_share(params = {}) ⇒ Types::UpdateAssessmentFrameworkShareResponse
Updates a share request for a custom framework in Audit Manager.
-
#update_assessment_status(params = {}) ⇒ Types::UpdateAssessmentStatusResponse
Updates the status of an assessment in Audit Manager.
-
#update_control(params = {}) ⇒ Types::UpdateControlResponse
Updates a custom control in Audit Manager.
-
#update_settings(params = {}) ⇒ Types::UpdateSettingsResponse
Updates Audit Manager settings for the current account.
-
#validate_assessment_report_integrity(params = {}) ⇒ Types::ValidateAssessmentReportIntegrityResponse
Validates the integrity of an assessment report in Audit Manager.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-auditmanager/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4088 4089 4090 |
# File 'lib/aws-sdk-auditmanager/client.rb', line 4088 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4091 4092 4093 |
# File 'lib/aws-sdk-auditmanager/client.rb', line 4091 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_assessment_report_evidence_folder(params = {}) ⇒ Struct
Associates an evidence folder to an assessment report in an Audit Manager assessment.
85 |
# File 'sig/client.rbs', line 85
def associate_assessment_report_evidence_folder: (
|
#batch_associate_assessment_report_evidence(params = {}) ⇒ Types::BatchAssociateAssessmentReportEvidenceResponse
Associates a list of evidence to an assessment report in an Audit Manager assessment.
97 |
# File 'sig/client.rbs', line 97
def batch_associate_assessment_report_evidence: (
|
#batch_create_delegation_by_assessment(params = {}) ⇒ Types::BatchCreateDelegationByAssessmentResponse
Creates a batch of delegations for an assessment in Audit Manager.
110 |
# File 'sig/client.rbs', line 110
def batch_create_delegation_by_assessment: (
|
#batch_delete_delegation_by_assessment(params = {}) ⇒ Types::BatchDeleteDelegationByAssessmentResponse
Deletes a batch of delegations for an assessment in Audit Manager.
128 |
# File 'sig/client.rbs', line 128
def batch_delete_delegation_by_assessment: (
|
#batch_disassociate_assessment_report_evidence(params = {}) ⇒ Types::BatchDisassociateAssessmentReportEvidenceResponse
Disassociates a list of evidence from an assessment report in Audit Manager.
140 |
# File 'sig/client.rbs', line 140
def batch_disassociate_assessment_report_evidence: (
|
#batch_import_evidence_to_assessment_control(params = {}) ⇒ Types::BatchImportEvidenceToAssessmentControlResponse
Adds one or more pieces of evidence to a control in an Audit Manager assessment.
You can import manual evidence from any S3 bucket by specifying the S3 URI of the object. You can also upload a file from your browser, or enter plain text in response to a risk assessment question.
The following restrictions apply to this action:
-
manualEvidencecan be only one of the following:evidenceFileName,s3ResourcePath, ortextResponse -
Maximum size of an individual evidence file: 100 MB
-
Number of daily manual evidence uploads per control: 100
-
Supported file formats: See Supported file types for manual evidence in the Audit Manager User Guide
For more information about Audit Manager service restrictions, see Quotas and restrictions for Audit Manager.
152 |
# File 'sig/client.rbs', line 152
def batch_import_evidence_to_assessment_control: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4061 4062 4063 4064 4065 4066 4067 4068 4069 4070 4071 4072 4073 4074 4075 4076 4077 |
# File 'lib/aws-sdk-auditmanager/client.rb', line 4061 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::AuditManager') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-auditmanager' context[:gem_version] = '1.85.0' Seahorse::Client::Request.new(handlers, context) end |
#create_assessment(params = {}) ⇒ Types::CreateAssessmentResponse
Creates an assessment in Audit Manager.
171 |
# File 'sig/client.rbs', line 171
def create_assessment: (
|
#create_assessment_framework(params = {}) ⇒ Types::CreateAssessmentFrameworkResponse
Creates a custom framework in Audit Manager.
195 |
# File 'sig/client.rbs', line 195
def create_assessment_framework: (
|
#create_assessment_report(params = {}) ⇒ Types::CreateAssessmentReportResponse
Creates an assessment report for the specified assessment.
218 |
# File 'sig/client.rbs', line 218
def create_assessment_report: (
|
#create_control(params = {}) ⇒ Types::CreateControlResponse
Creates a new custom control in Audit Manager.
231 |
# File 'sig/client.rbs', line 231
def create_control: (
|
#delete_assessment(params = {}) ⇒ Struct
Deletes an assessment in Audit Manager.
259 |
# File 'sig/client.rbs', line 259
def delete_assessment: (
|
#delete_assessment_framework(params = {}) ⇒ Struct
Deletes a custom framework in Audit Manager.
268 |
# File 'sig/client.rbs', line 268
def delete_assessment_framework: (
|
#delete_assessment_framework_share(params = {}) ⇒ Struct
Deletes a share request for a custom framework in Audit Manager.
277 |
# File 'sig/client.rbs', line 277
def delete_assessment_framework_share: (
|
#delete_assessment_report(params = {}) ⇒ Struct
Deletes an assessment report in Audit Manager.
When you run the DeleteAssessmentReport operation, Audit Manager
attempts to delete the following data:
-
The specified assessment report that’s stored in your S3 bucket
-
The associated metadata that’s stored in Audit Manager
If Audit Manager can’t access the assessment report in your S3 bucket,
the report isn’t deleted. In this event, the DeleteAssessmentReport
operation doesn’t fail. Instead, it proceeds to delete the associated
metadata only. You must then delete the assessment report from the S3
bucket yourself.
This scenario happens when Audit Manager receives a 403 (Forbidden)
or 404 (Not Found) error from Amazon S3. To avoid this, make sure
that your S3 bucket is available, and that you configured the correct
permissions for Audit Manager to delete resources in your S3 bucket.
For an example permissions policy that you can use, see Assessment
report destination permissions in the Audit Manager User Guide.
For information about the issues that could cause a 403 (Forbidden)
or 404 (Not Found) error from Amazon S3, see List of Error
Codes in the Amazon Simple Storage Service API Reference.
287 |
# File 'sig/client.rbs', line 287
def delete_assessment_report: (
|
#delete_control(params = {}) ⇒ Struct
Deletes a custom control in Audit Manager.
When you invoke this operation, the custom control is deleted from any frameworks or assessments that it’s currently part of. As a result, Audit Manager will stop collecting evidence for that custom control in all of your assessments. This includes assessments that you previously created before you deleted the custom control.
297 |
# File 'sig/client.rbs', line 297
def delete_control: (
|
#deregister_account(params = {}) ⇒ Types::DeregisterAccountResponse
Deregisters an account in Audit Manager.
DeregistrationPolicy attribute to request the deletion
of your data.
For more information about data retention, see Data Protection in the Audit Manager User Guide.
307 |
# File 'sig/client.rbs', line 307
def deregister_account: (
|
#deregister_organization_admin_account(params = {}) ⇒ Struct
Removes the specified Amazon Web Services account as a delegated administrator for Audit Manager.
When you remove a delegated administrator from your Audit Manager settings, you continue to have access to the evidence that you previously collected under that account. This is also the case when you deregister a delegated administrator from Organizations. However, Audit Manager stops collecting and attaching evidence to that delegated administrator account moving forward.
Keep in mind the following cleanup task if you use evidence finder:
Before you use your management account to remove a delegated administrator, make sure that the current delegated administrator account signs in to Audit Manager and disables evidence finder first. Disabling evidence finder automatically deletes the event data store that was created in their account when they enabled evidence finder. If this task isn’t completed, the event data store remains in their account. In this case, we recommend that the original delegated administrator goes to CloudTrail Lake and manually deletes the event data store.
This cleanup task is necessary to ensure that you don't end up with multiple event data stores. Audit Manager ignores an unused event data store after you remove or change a delegated administrator account. However, the unused event data store continues to incur storage costs from CloudTrail Lake if you don't delete it.
When you deregister a delegated administrator account for Audit Manager, the data for that account isn’t deleted. If you want to delete resource data for a delegated administrator account, you must perform that task separately before you deregister the account. Either, you can do this in the Audit Manager console. Or, you can use one of the delete API operations that are provided by Audit Manager.
To delete your Audit Manager resource data, see the following instructions:
-
DeleteAssessment (see also: Deleting an assessment in the Audit Manager User Guide)
-
DeleteAssessmentFramework (see also: Deleting a custom framework in the Audit Manager User Guide)
-
DeleteAssessmentFrameworkShare (see also: Deleting a share request in the Audit Manager User Guide)
-
DeleteAssessmentReport (see also: Deleting an assessment report in the Audit Manager User Guide)
-
DeleteControl (see also: Deleting a custom control in the Audit Manager User Guide)
At this time, Audit Manager doesn't provide an option to delete evidence for a specific delegated administrator. Instead, when your management account deregisters Audit Manager, we perform a cleanup for the current delegated administrator account at the time of deregistration.
315 |
# File 'sig/client.rbs', line 315
def deregister_organization_admin_account: (
|
#disassociate_assessment_report_evidence_folder(params = {}) ⇒ Struct
Disassociates an evidence folder from the specified assessment report in Audit Manager.
324 |
# File 'sig/client.rbs', line 324
def disassociate_assessment_report_evidence_folder: (
|
#get_account_status(params = {}) ⇒ Types::GetAccountStatusResponse
Gets the registration status of an account in Audit Manager.
335 |
# File 'sig/client.rbs', line 335
def get_account_status: (
|
#get_assessment(params = {}) ⇒ Types::GetAssessmentResponse
Gets information about a specified assessment.
345 |
# File 'sig/client.rbs', line 345
def get_assessment: (
|
#get_assessment_framework(params = {}) ⇒ Types::GetAssessmentFrameworkResponse
Gets information about a specified framework.
355 |
# File 'sig/client.rbs', line 355
def get_assessment_framework: (
|
#get_assessment_report_url(params = {}) ⇒ Types::GetAssessmentReportUrlResponse
Gets the URL of an assessment report in Audit Manager.
365 |
# File 'sig/client.rbs', line 365
def get_assessment_report_url: (
|
#get_change_logs(params = {}) ⇒ Types::GetChangeLogsResponse
Gets a list of changelogs from Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
377 |
# File 'sig/client.rbs', line 377
def get_change_logs: (
|
#get_control(params = {}) ⇒ Types::GetControlResponse
Gets information about a specified control.
391 |
# File 'sig/client.rbs', line 391
def get_control: (
|
#get_delegations(params = {}) ⇒ Types::GetDelegationsResponse
Gets a list of delegations from an audit owner to a delegate.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
402 |
# File 'sig/client.rbs', line 402
def get_delegations: (
|
#get_evidence(params = {}) ⇒ Types::GetEvidenceResponse
Gets information about a specified evidence item.
413 |
# File 'sig/client.rbs', line 413
def get_evidence: (
|
#get_evidence_by_evidence_folder(params = {}) ⇒ Types::GetEvidenceByEvidenceFolderResponse
Gets all evidence from a specified evidence folder in Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
427 |
# File 'sig/client.rbs', line 427
def get_evidence_by_evidence_folder: (
|
#get_evidence_file_upload_url(params = {}) ⇒ Types::GetEvidenceFileUploadUrlResponse
Creates a presigned Amazon S3 URL that can be used to upload a file as manual evidence. For instructions on how to use this operation, see Upload a file from your browser in the Audit Manager User Guide.
The following restrictions apply to this operation:
-
Maximum size of an individual evidence file: 100 MB
-
Number of daily manual evidence uploads per control: 100
-
Supported file formats: See Supported file types for manual evidence in the Audit Manager User Guide
For more information about Audit Manager service restrictions, see Quotas and restrictions for Audit Manager.
442 |
# File 'sig/client.rbs', line 442
def get_evidence_file_upload_url: (
|
#get_evidence_folder(params = {}) ⇒ Types::GetEvidenceFolderResponse
Gets an evidence folder from a specified assessment in Audit Manager.
452 |
# File 'sig/client.rbs', line 452
def get_evidence_folder: (
|
#get_evidence_folders_by_assessment(params = {}) ⇒ Types::GetEvidenceFoldersByAssessmentResponse
Gets the evidence folders from a specified assessment in Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
465 |
# File 'sig/client.rbs', line 465
def get_evidence_folders_by_assessment: (
|
#get_evidence_folders_by_assessment_control(params = {}) ⇒ Types::GetEvidenceFoldersByAssessmentControlResponse
Gets a list of evidence folders that are associated with a specified control in an Audit Manager assessment.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
478 |
# File 'sig/client.rbs', line 478
def get_evidence_folders_by_assessment_control: (
|
#get_insights(params = {}) ⇒ Types::GetInsightsResponse
Gets the latest analytics data for all your current active assessments.
492 |
# File 'sig/client.rbs', line 492
def get_insights: (
|
#get_insights_by_assessment(params = {}) ⇒ Types::GetInsightsByAssessmentResponse
Gets the latest analytics data for a specific active assessment.
501 |
# File 'sig/client.rbs', line 501
def get_insights_by_assessment: (
|
#get_organization_admin_account(params = {}) ⇒ Types::GetOrganizationAdminAccountResponse
Gets the name of the delegated Amazon Web Services administrator account for a specified organization.
512 |
# File 'sig/client.rbs', line 512
def get_organization_admin_account: (
|
#get_services_in_scope(params = {}) ⇒ Types::GetServicesInScopeResponse
Gets a list of the Amazon Web Services services from which Audit Manager can collect evidence.
Audit Manager defines which Amazon Web Services services are in scope for an assessment. Audit Manager infers this scope by examining the assessment’s controls and their data sources, and then mapping this information to one or more of the corresponding Amazon Web Services services that are in this list.
521 |
# File 'sig/client.rbs', line 521
def get_services_in_scope: (
|
#get_settings(params = {}) ⇒ Types::GetSettingsResponse
Gets the settings for a specified Amazon Web Services account.
530 |
# File 'sig/client.rbs', line 530
def get_settings: (
|
#list_assessment_control_insights_by_control_domain(params = {}) ⇒ Types::ListAssessmentControlInsightsByControlDomainResponse
Lists the latest analytics data for controls within a specific control domain and a specific active assessment.
lastUpdated date of
controlInsightsByAssessment. If neither of these conditions are met,
no data is listed for that control.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
541 |
# File 'sig/client.rbs', line 541
def list_assessment_control_insights_by_control_domain: (
|
#list_assessment_framework_share_requests(params = {}) ⇒ Types::ListAssessmentFrameworkShareRequestsResponse
Returns a list of sent or received share requests for custom frameworks in Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
555 |
# File 'sig/client.rbs', line 555
def list_assessment_framework_share_requests: (
|
#list_assessment_frameworks(params = {}) ⇒ Types::ListAssessmentFrameworksResponse
Returns a list of the frameworks that are available in the Audit Manager framework library.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
568 |
# File 'sig/client.rbs', line 568
def list_assessment_frameworks: (
|
#list_assessment_reports(params = {}) ⇒ Types::ListAssessmentReportsResponse
Returns a list of assessment reports created in Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
581 |
# File 'sig/client.rbs', line 581
def list_assessment_reports: (
|
#list_assessments(params = {}) ⇒ Types::ListAssessmentsResponse
Returns a list of current and past assessments from Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
593 |
# File 'sig/client.rbs', line 593
def list_assessments: (
|
#list_control_domain_insights(params = {}) ⇒ Types::ListControlDomainInsightsResponse
Lists the latest analytics data for control domains across all of your active assessments.
Audit Manager supports the control domains that are provided by Amazon
Web Services Control Catalog. For information about how to find a list
of available control domains, see ListDomains in the Amazon
Web Services Control Catalog API Reference.
lastUpdated date of
controlDomainInsights. If this condition isn’t met, no data is
listed for that control domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
606 |
# File 'sig/client.rbs', line 606
def list_control_domain_insights: (
|
#list_control_domain_insights_by_assessment(params = {}) ⇒ Types::ListControlDomainInsightsByAssessmentResponse
Lists analytics data for control domains within a specified active assessment.
Audit Manager supports the control domains that are provided by Amazon
Web Services Control Catalog. For information about how to find a list
of available control domains, see ListDomains in the Amazon
Web Services Control Catalog API Reference.
lastUpdated date of
controlDomainInsights. If this condition isn’t met, no data is
listed for that domain.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
618 |
# File 'sig/client.rbs', line 618
def list_control_domain_insights_by_assessment: (
|
#list_control_insights_by_control_domain(params = {}) ⇒ Types::ListControlInsightsByControlDomainResponse
Lists the latest analytics data for controls within a specific control domain across all active assessments.
lastUpdated date of controlInsightsMetadata. If neither of these
conditions are met, no data is listed for that control.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
631 |
# File 'sig/client.rbs', line 631
def list_control_insights_by_control_domain: (
|
#list_controls(params = {}) ⇒ Types::ListControlsResponse
Returns a list of controls from Audit Manager.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
644 |
# File 'sig/client.rbs', line 644
def list_controls: (
|
#list_keywords_for_data_source(params = {}) ⇒ Types::ListKeywordsForDataSourceResponse
Returns a list of keywords that are pre-mapped to the specified control data source.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
658 |
# File 'sig/client.rbs', line 658
def list_keywords_for_data_source: (
|
#list_notifications(params = {}) ⇒ Types::ListNotificationsResponse
Returns a list of all Audit Manager notifications.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
671 |
# File 'sig/client.rbs', line 671
def list_notifications: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for the specified resource in Audit Manager.
682 |
# File 'sig/client.rbs', line 682
def list_tags_for_resource: (
|
#register_account(params = {}) ⇒ Types::RegisterAccountResponse
Enables Audit Manager for the specified Amazon Web Services account.
692 |
# File 'sig/client.rbs', line 692
def register_account: (
|
#register_organization_admin_account(params = {}) ⇒ Types::RegisterOrganizationAdminAccountResponse
Enables an Amazon Web Services account within the organization as the delegated administrator for Audit Manager.
704 |
# File 'sig/client.rbs', line 704
def register_organization_admin_account: (
|
#start_assessment_framework_share(params = {}) ⇒ Types::StartAssessmentFrameworkShareResponse
Creates a share request for a custom framework in Audit Manager.
The share request specifies a recipient and notifies them that a custom framework is available. Recipients have 120 days to accept or decline the request. If no action is taken, the share request expires.
When you create a share request, Audit Manager stores a snapshot of your custom framework in the US East (N. Virginia) Amazon Web Services Region. Audit Manager also stores a backup of the same snapshot in the US West (Oregon) Amazon Web Services Region.
Audit Manager deletes the snapshot and the backup snapshot when one of the following events occurs:
-
The sender revokes the share request.
-
The recipient declines the share request.
-
The recipient encounters an error and doesn't successfully accept the share request.
-
The share request expires before the recipient responds to the request.
When a sender resends a share request, the snapshot is replaced with an updated version that corresponds with the latest version of the custom framework.
When a recipient accepts a share request, the snapshot is replicated into their Amazon Web Services account under the Amazon Web Services Region that was specified in the share request.
When you invoke the StartAssessmentFrameworkShare API, you are about
to share a custom framework with another Amazon Web Services account.
You may not share a custom framework that is derived from a standard
framework if the standard framework is designated as not eligible for
sharing by Amazon Web Services, unless you have obtained permission to
do so from the owner of the standard framework. To learn more about
which standard frameworks are eligible for sharing, see Framework
sharing eligibility in the Audit Manager User Guide.
714 |
# File 'sig/client.rbs', line 714
def start_assessment_framework_share: (
|
#tag_resource(params = {}) ⇒ Struct
Tags the specified resource in Audit Manager.
726 |
# File 'sig/client.rbs', line 726
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag from a resource in Audit Manager.
736 |
# File 'sig/client.rbs', line 736
def untag_resource: (
|
#update_assessment(params = {}) ⇒ Types::UpdateAssessmentResponse
Edits an Audit Manager assessment.
747 |
# File 'sig/client.rbs', line 747
def update_assessment: (
|
#update_assessment_control(params = {}) ⇒ Types::UpdateAssessmentControlResponse
Updates a control within an assessment in Audit Manager.
770 |
# File 'sig/client.rbs', line 770
def update_assessment_control: (
|
#update_assessment_control_set_status(params = {}) ⇒ Types::UpdateAssessmentControlSetStatusResponse
Updates the status of a control set in an Audit Manager assessment.
784 |
# File 'sig/client.rbs', line 784
def update_assessment_control_set_status: (
|
#update_assessment_framework(params = {}) ⇒ Types::UpdateAssessmentFrameworkResponse
Updates a custom framework in Audit Manager.
797 |
# File 'sig/client.rbs', line 797
def update_assessment_framework: (
|
#update_assessment_framework_share(params = {}) ⇒ Types::UpdateAssessmentFrameworkShareResponse
Updates a share request for a custom framework in Audit Manager.
821 |
# File 'sig/client.rbs', line 821
def update_assessment_framework_share: (
|
#update_assessment_status(params = {}) ⇒ Types::UpdateAssessmentStatusResponse
Updates the status of an assessment in Audit Manager.
833 |
# File 'sig/client.rbs', line 833
def update_assessment_status: (
|
#update_control(params = {}) ⇒ Types::UpdateControlResponse
Updates a custom control in Audit Manager.
844 |
# File 'sig/client.rbs', line 844
def update_control: (
|
#update_settings(params = {}) ⇒ Types::UpdateSettingsResponse
Updates Audit Manager settings for the current account.
874 |
# File 'sig/client.rbs', line 874
def update_settings: (
|
#validate_assessment_report_integrity(params = {}) ⇒ Types::ValidateAssessmentReportIntegrityResponse
Validates the integrity of an assessment report in Audit Manager.
907 |
# File 'sig/client.rbs', line 907
def validate_assessment_report_integrity: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4081 4082 4083 |
# File 'lib/aws-sdk-auditmanager/client.rb', line 4081 def waiter_names [] end |