Class: Aws::AuditManager::Types::AssessmentMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

The metadata that's associated with the specified assessment.

Constant Summary collapse

SENSITIVE =
[:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]

Instance Attribute Summary collapse

Instance Attribute Details

#assessment_reports_destination ⇒ Types::AssessmentReportsDestination

The destination that evidence reports are stored in for the assessment.



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#compliance_type ⇒ String

The name of the compliance standard that's related to the assessment, such as PCI-DSS.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#creation_time ⇒ Time

Specifies when the assessment was created.

Returns:

  • (Time)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#delegations ⇒ Array<Types::Delegation>

The delegations that are associated with the assessment.

Returns:



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#description ⇒ String

The description of the assessment.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#id ⇒ String

The unique identifier for the assessment.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#last_updated ⇒ Time

The time of the most recent update.

Returns:

  • (Time)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#name ⇒ String

The name of the assessment.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#roles ⇒ Array<Types::Role>

The roles that are associated with the assessment.

Returns:



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#scope ⇒ Types::Scope

The wrapper of Amazon Web Services accounts and services that are in scope for the assessment.

Returns:



570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end

#status ⇒ String

The overall status of the assessment.

Returns:

  • (String)


570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
# File 'lib/aws-sdk-auditmanager/types.rb', line 570

class AssessmentMetadata < Struct.new(
  :name,
  :id,
  :description,
  :compliance_type,
  :status,
  :assessment_reports_destination,
  :scope,
  :roles,
  :delegations,
  :creation_time,
  :last_updated)
  SENSITIVE = [:name, :description, :compliance_type, :assessment_reports_destination, :scope, :roles, :delegations]
  include Aws::Structure
end