Class: Aws::AuditManager::Types::AssessmentReport

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

A finalized document that's generated from an Audit Manager assessment. These reports summarize the relevant evidence that was collected for your audit, and link to the relevant evidence folders. These evidence folders are named and organized according to the controls that are specified in your assessment.

Constant Summary collapse

SENSITIVE =
[:description, :assessment_name, :author]

Instance Attribute Summary collapse

Instance Attribute Details

#assessment_id ⇒ String

The identifier for the specified assessment.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#assessment_name ⇒ String

The name of the associated assessment.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#author ⇒ String

The name of the user who created the assessment report.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#aws_account_id ⇒ String

The identifier for the specified Amazon Web Services account.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#creation_time ⇒ Time

Specifies when the assessment report was created.

Returns:

  • (Time)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#description ⇒ String

The description of the specified assessment report.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#id ⇒ String

The unique identifier for the assessment report.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#name ⇒ String

The name that's given to the assessment report.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end

#status ⇒ String

The current status of the specified assessment report.

Returns:

  • (String)


681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'lib/aws-sdk-auditmanager/types.rb', line 681

class AssessmentReport < Struct.new(
  :id,
  :name,
  :description,
  :aws_account_id,
  :assessment_id,
  :assessment_name,
  :author,
  :status,
  :creation_time)
  SENSITIVE = [:description, :assessment_name, :author]
  include Aws::Structure
end