Class: Aws::AuditManager::Types::Control

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

A control in Audit Manager.

Constant Summary collapse

SENSITIVE =
[:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]

Instance Attribute Summary collapse

Instance Attribute Details

#action_plan_instructions ⇒ String

The recommended actions to carry out if the control isn't fulfilled.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#action_plan_title ⇒ String

The title of the action plan for remediating the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#arn ⇒ String

The Amazon Resource Name (ARN) of the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#control_mapping_sources ⇒ Array<Types::ControlMappingSource>

The data mapping sources for the control.

Returns:



1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#control_sources ⇒ String

The data source types that determine where Audit Manager collects evidence from for the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#created_at ⇒ Time

The time when the control was created.

Returns:

  • (Time)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#created_by ⇒ String

The user or role that created the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#description ⇒ String

The description of the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#id ⇒ String

The unique identifier for the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#last_updated_at ⇒ Time

The time when the control was most recently updated.

Returns:

  • (Time)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#last_updated_by ⇒ String

The user or role that most recently updated the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#name ⇒ String

The name of the control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#state ⇒ String

The state of the control. The END_OF_SUPPORT state is applicable to standard controls only. This state indicates that the standard control can still be used to collect evidence, but Audit Manager is no longer updating or maintaining that control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

The tags associated with the control.

Returns:

  • (Hash<String,String>)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#testing_information ⇒ String

The steps that you should follow to determine if the control has been satisfied.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end

#type ⇒ String

Specifies whether the control is a standard control or a custom control.

Returns:

  • (String)


1196
1197
1198
1199
1200
1201
1202
1203
1204
1205
1206
1207
1208
1209
1210
1211
1212
1213
1214
1215
# File 'lib/aws-sdk-auditmanager/types.rb', line 1196

class Control < Struct.new(
  :arn,
  :id,
  :type,
  :name,
  :description,
  :testing_information,
  :action_plan_title,
  :action_plan_instructions,
  :control_sources,
  :control_mapping_sources,
  :created_at,
  :last_updated_at,
  :created_by,
  :last_updated_by,
  :tags,
  :state)
  SENSITIVE = [:description, :testing_information, :action_plan_title, :action_plan_instructions, :created_by, :last_updated_by]
  include Aws::Structure
end