Class: Aws::AuditManager::Types::ControlMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

The metadata that's associated with the standard control or custom control.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the control.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#control_sources ⇒ String

The data source that determines where Audit Manager collects evidence from for the control.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_at ⇒ Time

The time when the control was created.

Returns:

  • (Time)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier for the control.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#last_updated_at ⇒ Time

The time when the control was most recently updated.

Returns:

  • (Time)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the control.

Returns:

  • (String)


1486
1487
1488
1489
1490
1491
1492
1493
1494
1495
# File 'lib/aws-sdk-auditmanager/types.rb', line 1486

class ControlMetadata < Struct.new(
  :arn,
  :id,
  :name,
  :control_sources,
  :created_at,
  :last_updated_at)
  SENSITIVE = []
  include Aws::Structure
end