Class: Aws::AuditManager::Types::CreateAssessmentResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::AuditManager::Types::CreateAssessmentResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-auditmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#assessment ⇒ Types::Assessment
An entity that defines the scope of audit evidence collected by Audit Manager.
Instance Attribute Details
#assessment ⇒ Types::Assessment
An entity that defines the scope of audit evidence collected by Audit Manager. An Audit Manager assessment is an implementation of an Audit Manager framework.
1738 1739 1740 1741 1742 |
# File 'lib/aws-sdk-auditmanager/types.rb', line 1738 class CreateAssessmentResponse < Struct.new( :assessment) SENSITIVE = [] include Aws::Structure end |