Class: Aws::AuditManager::Types::Resource

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

A system asset that’s evaluated in an Audit Manager assessment.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) for the resource.

Returns:

  • (String)


4041
4042
4043
4044
4045
4046
4047
# File 'lib/aws-sdk-auditmanager/types.rb', line 4041

class Resource < Struct.new(
  :arn,
  :value,
  :compliance_check)
  SENSITIVE = []
  include Aws::Structure
end

#compliance_checkString

The evaluation status for a resource that was assessed when collecting compliance check evidence.

  • Audit Manager classes the resource as non-compliant if Security Hub CSPM reports a Fail result, or if Config reports a Non-compliant result.

  • Audit Manager classes the resource as compliant if Security Hub CSPM reports a Pass result, or if Config reports a Compliant result.

  • If a compliance check isn’t available or applicable, then no compliance evaluation can be made for that resource. This is the case if a resource assessment uses Config or Security Hub CSPM as the underlying data source type, but those services aren’t enabled. This is also the case if the resource assessment uses an underlying data source type that doesn’t support compliance checks (such as manual evidence, Amazon Web Services API calls, or CloudTrail).

Returns:

  • (String)


4041
4042
4043
4044
4045
4046
4047
# File 'lib/aws-sdk-auditmanager/types.rb', line 4041

class Resource < Struct.new(
  :arn,
  :value,
  :compliance_check)
  SENSITIVE = []
  include Aws::Structure
end

#valueString

The value of the resource.

Returns:

  • (String)


4041
4042
4043
4044
4045
4046
4047
# File 'lib/aws-sdk-auditmanager/types.rb', line 4041

class Resource < Struct.new(
  :arn,
  :value,
  :compliance_check)
  SENSITIVE = []
  include Aws::Structure
end