Class: Aws::AuditManager::Types::UpdateSettingsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-auditmanager/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:default_assessment_reports_destination, :default_process_owners]

Instance Attribute Summary collapse

Instance Attribute Details

#default_assessment_reports_destinationTypes::AssessmentReportsDestination

The default S3 destination bucket for storing assessment reports.



4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#default_export_destinationTypes::DefaultExportDestination

The default S3 destination bucket for storing evidence finder exports.



4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#default_process_ownersArray<Types::Role>

A list of the default audit owners.

Returns:



4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#deregistration_policyTypes::DeregistrationPolicy

The deregistration policy for your Audit Manager data. You can use this attribute to determine how your data is handled when you deregister Audit Manager.



4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#evidence_finder_enabledBoolean

Specifies whether the evidence finder feature is enabled. Change this attribute to enable or disable evidence finder.

When you use this attribute to disable evidence finder, Audit Manager deletes the event data store that’s used to query your evidence data. As a result, you can’t re-enable evidence finder and use the feature again. Your only alternative is to [deregister] and then [re-register] Audit Manager.

[1]: docs.aws.amazon.com/audit-manager/latest/APIReference/API_DeregisterAccount.html [2]: docs.aws.amazon.com/audit-manager/latest/APIReference/API_RegisterAccount.html

Returns:

  • (Boolean)


4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#kms_keyString

The KMS key details.

Returns:

  • (String)


4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end

#sns_topicString

The Amazon Simple Notification Service (Amazon SNS) topic that Audit Manager sends notifications to.

Returns:

  • (String)


4900
4901
4902
4903
4904
4905
4906
4907
4908
4909
4910
# File 'lib/aws-sdk-auditmanager/types.rb', line 4900

class UpdateSettingsRequest < Struct.new(
  :sns_topic,
  :default_assessment_reports_destination,
  :default_process_owners,
  :kms_key,
  :evidence_finder_enabled,
  :deregistration_policy,
  :default_export_destination)
  SENSITIVE = [:default_assessment_reports_destination, :default_process_owners]
  include Aws::Structure
end