Class: Aws::AuditManager::Types::ListControlsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::AuditManager::Types::ListControlsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-auditmanager/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#control_catalog_id ⇒ String
A filter that narrows the list of controls to a specific resource from the Amazon Web Services Control Catalog.
-
#control_type ⇒ String
A filter that narrows the list of controls to a specific type.
-
#max_results ⇒ Integer
The maximum number of results on a page or for an API request call.
-
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
Instance Attribute Details
#control_catalog_id ⇒ String
A filter that narrows the list of controls to a specific resource from the Amazon Web Services Control Catalog.
To use this parameter, specify the ARN of the Control Catalog
resource. You can specify either a control domain, a control
objective, or a common control. For information about how to find
the ARNs for these resources, see ListDomains ,
ListObjectives , and ListCommonControls .
ListControls operation separately for each ARN.
Alternatively, specify UNCATEGORIZED to list controls that aren't
mapped to a Control Catalog resource. For example, this operation
might return a list of custom controls that don't belong to any
control domain or control objective.
3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-auditmanager/types.rb', line 3738 class ListControlsRequest < Struct.new( :control_type, :next_token, :max_results, :control_catalog_id) SENSITIVE = [] include Aws::Structure end |
#control_type ⇒ String
A filter that narrows the list of controls to a specific type.
3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-auditmanager/types.rb', line 3738 class ListControlsRequest < Struct.new( :control_type, :next_token, :max_results, :control_catalog_id) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results on a page or for an API request call.
3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-auditmanager/types.rb', line 3738 class ListControlsRequest < Struct.new( :control_type, :next_token, :max_results, :control_catalog_id) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The pagination token that's used to fetch the next set of results.
3738 3739 3740 3741 3742 3743 3744 3745 |
# File 'lib/aws-sdk-auditmanager/types.rb', line 3738 class ListControlsRequest < Struct.new( :control_type, :next_token, :max_results, :control_catalog_id) SENSITIVE = [] include Aws::Structure end |